@@ -5,27 +5,25 @@ OC.L10N.register(
     "Error" : "Error",
     "New note" : "Nota nueva",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
-    "Action" : "Acción",
     "Open in edit mode" : "Abrir en modo edición",
     "Open in preview mode" : "Abrir en modo previsualización",
+    "Action" : "Acción",
     "All notes" : "Todas las notas",
     "Categories" : "Categorías",
     "No notes yet" : "Aún no hay notas",
-    "Details" : "Detalles",
-    "Delete note" : "Borrar nota",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a tus favoritos",
+    "Share" : "Compartir",
+    "Rename" : "Rename",
+    "Delete note" : "Borrar nota",
     "Edit" : "Editar",
     "Preview" : "Previsualizar",
-    "Loading …" : "Cargando …",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
     "This week" : "Esta semana",
     "This month" : "Este mes",
-    "Category" : "Categoría",
+    "Loading …" : "Cargando …",
     "Uncategorized" : "Sin categoría",
-    "Saving failed!" : "¡Falla al guardar!",
-    "_%n word_::_%n words_" : ["%n palabra","%n palabras","%n palabras"],
     "Tasks" : "Tareas"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
