@@ -4,30 +4,25 @@ OC.L10N.register(
     "Notes" : "Notas",
     "Error" : "Error",
     "New note" : "Nota nueva",
-    "Help" : "Ayuda",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
-    "Result" : "Resultado",
-    "Action" : "Acción",
     "Open in edit mode" : "Abrir en modo edición",
     "Open in preview mode" : "Abrir en modo previsualización",
-    "No notes yet" : "Aún no hay notas",
+    "Action" : "Acción",
     "All notes" : "Todas las notas",
     "Categories" : "Categorías",
+    "No notes yet" : "Aún no hay notas",
+    "Remove from favorites" : "Eliminar de favoritos",
+    "Add to favorites" : "Agregar a tus favoritos",
+    "Share" : "Compartir",
+    "Rename" : "Renombrar",
+    "Delete note" : "Borrar nota",
+    "Edit" : "Editar",
+    "Preview" : "Previsualizar",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
     "This week" : "Esta semana",
     "This month" : "Este mes",
-    "Rename" : "Renombrar",
-    "Details" : "Detalles",
-    "Delete note" : "Borrar nota",
-    "Remove from favorites" : "Eliminar de favoritos",
-    "Add to favorites" : "Agregar a tus favoritos",
-    "Edit" : "Editar",
-    "Preview" : "Previsualizar",
-    "Category" : "Categoría",
     "Uncategorized" : "Sin categoría",
-    "Saving failed!" : "¡Falla al guardar!",
-    "_%n word_::_%n words_" : ["%n palabra","%n palabras","%n palabras"],
     "Tasks" : "Tareas"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
