@@ -2,30 +2,20 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Muistiinpanot",
+    "Create new note" : "Luo uusi muistiinpano",
+    "More notes" : "Lisää muistiinpanoja",
     "Reading notes from filesystem has failed." : "Muistiinpanojen lukeminen tiedostojärjestelmästä epäonnistui.",
     "Error" : "Virhe",
     "New note" : "Uusi muistiinpano",
     "Distraction-free notes and writing" : "Häiriötöntä muistiinpanojen ottamista ja kirjoittamista",
-    "Notes settings" : "Asetukset",
-    "Please see Nextcloud server log for details." : "Katso lisätietoja Nextcloud-palvelimen lokista.",
     "Deleted {title}" : "Poistettu {title}",
+    "_Deleted {number} note_::_Deleted {number} notes_" : ["Poistettu {number} muistiinpano","Poistettu {number} muistiinpanoa"],
     "Undo Delete" : "Kumoa",
     "Note recovered" : "Muistiinpano palautettu",
-    "There are unsaved notes. Leaving the page will discard all changes!" : "Havaittiin tallentamattomia muistiinpanoja. Sivulta poistuminen hylkää kaikki muutokset!",
-    "_Deleted {number} note_::_Deleted {number} notes_" : ["Poistettu {number} muistiinpano","Poistettu {number} muistiinpanoa"],
     "_Recovered {number} note_::_Recovered {number} notes_" : ["Palautettu {number} muistiinpano","Palautettu {number} muistiinpanoa"],
-    "Basics" : "Perusteet",
-    "Write down your thoughts without any distractions." : "Kirjaa ajatuksesi ilman häiriötekijöitä.",
-    "Organize your notes in categories." : "Organisoi muistiinpanosi luokkiin.",
-    "Folder to store your notes" : "Kansio johon muistiinpanot tallennetaan",
-    "Root directory" : "Juurihakemisto",
-    "File extension for new notes" : "Tiedostopääte uusille muistiinpanoille",
-    "Display mode for notes" : "Muistiinpanojen esitystapa",
-    "Shortcuts" : "Pikanäppäimet",
-    "Use shortcuts to quickly navigate this app." : "Käytä pikanäppäimiä nopeaan siirtymiseen sovelluksessa.",
-    "Shortcut" : "Pikanäppäin",
-    "Action" : "Toiminto",
-    "Mobile apps" : "Mobiilisovellukset",
+    "There are unsaved notes. Leaving the page will discard all changes!" : "Havaittiin tallentamattomia muistiinpanoja. Sivulta poistuminen hylkää kaikki muutokset!",
+    "Notes settings" : "Asetukset",
+    "Please see Nextcloud server log for details." : "Katso lisätietoja Nextcloud-palvelimen lokista.",
     "User defined" : "Käyttäjän määrittelemä",
     "Open in edit mode" : "Avaa muokkaustilassa",
     "Open in preview mode" : "Avaa esikatselutilassa",
@@ -44,21 +34,42 @@ OC.L10N.register(
     "Insert link" : "Lisää linkki",
     "Insert image" : "Lisää kuva",
     "Switch between editor and viewer" : "Vaihda muokkaus- ja katselutilan välllä",
+    "Basics" : "Perusteet",
+    "Write down your thoughts without any distractions." : "Kirjaa ajatuksesi ilman häiriötekijöitä.",
+    "Organize your notes in categories." : "Organisoi muistiinpanosi luokkiin.",
+    "Notes path" : "Muistiinpanojen polku",
+    "Folder to store your notes" : "Kansio johon muistiinpanot tallennetaan",
+    "Root directory" : "Juurihakemisto",
+    "File extension" : "Tiedostopääte",
+    "File extension for new notes" : "Tiedostopääte uusille muistiinpanoille",
+    "Display mode" : "Näyttötila",
+    "Display mode for notes" : "Muistiinpanojen esitystapa",
+    "Shortcuts" : "Pikanäppäimet",
+    "Use shortcuts to quickly navigate this app." : "Käytä pikanäppäimiä nopeaan siirtymiseen sovelluksessa.",
+    "Shortcut" : "Pikanäppäin",
+    "Action" : "Toiminto",
+    "Mobile apps" : "Mobiilisovellukset",
     "All notes" : "Kaikki muistiinpanot",
     "Categories" : "Luokat",
     "No notes yet" : "Ei muistiinpanoja",
-    "Upload image" : "Lataa kuva",
     "Select an image" : "Valitse kuva",
     "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Et voi valita kuvia muistiinpanohakemiston ulkopuolelta. Muistiinpanojesi hakemisto: {folder}",
     "Wrong image" : "Väärä kuva",
     "The file was not uploaded. Check your server logs." : "Tiedostoa ei ladattu. Tarkista palvelimen lokitiedot.",
+    "Upload image" : "Lataa kuva",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Asenna sovellus puhelimeesi käyttääksesi muistiinpanoja missä tahansa.",
-    "Share" : "Share",
-    "Rename" : "Rename",
-    "Delete note" : "Poista muistiinpano",
+    "Android app: {notes}" : "Android-sovellus: {notes}",
+    "iOS app: {notes}" : "iOS-sovellus: {notes}",
     "Remove from favorites" : "Poista suosikeista",
     "Add to favorites" : "Lisää suosikkeihin",
+    "Error while renaming note." : "Virhe muuttaessa muistiinpanon nimeä.",
     "Error during preparing note for deletion." : "Virhe valmisteltaessa muistiinpanon poistamista.",
+    "Share" : "Share",
+    "Change category" : "Vaihda luokkaa",
+    "Rename" : "Rename",
+    "Rename note" : "Nimeä muistiinpano uudelleen",
+    "Delete note" : "Poista muistiinpano",
+    "Error from Nextcloud server: {msg}" : "Virhe Nextcloud-palvelimelta: {msg}",
     "The note has been changed in another session. Please choose which version should be saved." : "Muistiinpanoa on muutettu toisessa sessiossa. Valitse, kumpi versio tallennetaan.",
     "Use version from server" : "Käytä versiota palvelimelta",
     "Use current version" : "Käytä nykyistä versiota",
@@ -72,14 +83,15 @@ OC.L10N.register(
     "Note is read-only. You cannot change it." : "Muistiinpano on kirjoitussuojattu. Et voi tehdä siihen muutoksia.",
     "Save failed. Click to retry." : "Tallennus epäonnistui. Napsauta yrittääksesi uudelleen.",
     "Update conflict. Click for resolving manually." : "Konflikti päivityksessä. Klikkaa ratkaistaksesi se manuaalisesti.",
-    "Error from Nextcloud server: {msg}" : "Virhe Nextcloud-palvelimelta: {msg}",
-    "Loading …" : "Ladataan…",
     "Today" : "Tänään",
     "Yesterday" : "Eilen",
     "This week" : "Tällä viikolla",
     "Last week" : "Viime viikolla",
     "This month" : "Tässä kuussa",
     "Last month" : "Viime kuussa",
+    "Search for notes" : "Etsi muistiinpanoja",
+    "Loading …" : "Ladataan…",
+    "Find in all categories" : "Etsi kaikista luokista",
     "Use Markdown markups to style your text." : "Käytä Markdown-merkintää tekstille.",
     "Start writing a note by clicking on “{newnote}” in the app navigation." : "Aloita muistiinpanon kirjoittaminen napauttamalla \"{newnote}\" navigoinnissa.",
     "Note not found." : "Muistiinpanoa ei löytynyt.",
