@@ -6,7 +6,6 @@ OC.L10N.register(
     "New note" : "Nòta ùr",
     "Display mode for notes" : "Modh sealladh nan nòtaichean",
     "All notes" : "A h-uile nòta",
-    "Details" : "Mion-fhiosrachadh",
     "Add to favorites" : "Cuir ris na h-annsachdan",
     "Edit" : "Deasaich",
     "Preview" : "Ro-sheall",
@@ -16,7 +15,6 @@ OC.L10N.register(
     "Last week" : "An t-seachdain seo chaidh",
     "This month" : "Am mìos seo",
     "Last month" : "Am mìos seo chaidh",
-    "Category" : "Roinn-seòrsa",
     "Uncategorized" : "Gun seòrsachadh"
 },
 "nplurals=4; plural=(n==1 || n==11) ? 0 : (n==2 || n==12) ? 1 : (n > 2 && n < 20) ? 2 : 3;");
