@@ -2,14 +2,14 @@ OC.L10N.register(
     "notes",
     {
     "Error" : "ຜິດພາດ",
-    "Share" : "ເເບ່ງປັນ",
-    "Rename" : "ປ່ຽນຊື່",
     "Remove from favorites" : "ຍ້າຍຈາກລາຍການທີ່ມັກ",
     "Add to favorites" : "ເພີ່ມລາຍການທີ່ມັກ",
+    "Share" : "ເເບ່ງປັນ",
+    "Rename" : "ປ່ຽນຊື່",
     "Edit" : "ແກ້ໄຂ",
-    "Loading …" : "ກຳລັງໂຫຼດ",
     "Today" : "ມື້ນີ້",
     "Yesterday" : "ມື້ວານນີ້",
-    "This week" : "ທິດນີ້"
+    "This week" : "ທິດນີ້",
+    "Loading …" : "ກຳລັງໂຫຼດ"
 },
 "nplurals=1; plural=0;");
