@@ -2,6 +2,11 @@
 
 declare(strict_types=1);
 
+/**
+ * SPDX-FileCopyrightText: 2023 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
+ */
+
 namespace OCA\Notes\AppInfo;
 
 use OCA\Notes\Service\NoteUtil;
@@ -9,16 +14,23 @@ use OCA\Notes\Service\SettingsService;
 use OCP\EventDispatcher\Event;
 use OCP\EventDispatcher\IEventListener;
 use OCP\Files\File;
+use OCP\IUserManager;
 use OCP\Share\Events\BeforeShareCreatedEvent;
 use OCP\Share\IShare;
 use Psr\Log\LoggerInterface;
 
+/** @template-implements IEventListener<BeforeShareCreatedEvent|Event> */
 class BeforeShareCreatedListener implements IEventListener {
 	private SettingsService $settings;
 	private NoteUtil $noteUtil;
 	private LoggerInterface $logger;
 
-	public function __construct(SettingsService $settings, NoteUtil $noteUtil, LoggerInterface $logger) {
+	public function __construct(
+		protected IUserManager $userManager,
+		SettingsService $settings,
+		NoteUtil $noteUtil,
+		LoggerInterface $logger,
+	) {
 		$this->settings = $settings;
 		$this->noteUtil = $noteUtil;
 		$this->logger = $logger;
@@ -49,8 +61,7 @@ class BeforeShareCreatedListener implements IEventListener {
 			$receiver = $share->getSharedWith();
 			$receiverPath = $this->noteUtil->getRoot()->getUserFolder($receiver)->getPath();
 			$receiverNotesInternalPath = $this->settings->get($receiver, 'notesPath');
-			$receiverNotesPath = $receiverPath . '/' . $receiverNotesInternalPath;
-			$this->noteUtil->getOrCreateFolder($receiverNotesPath);
+			$this->noteUtil->getOrCreateNotesFolder($receiver);
 
 			if ($itemType !== 'file' || strpos($fileSourcePath, $ownerNotesPath) !== 0) {
 				return;
@@ -58,6 +69,12 @@ class BeforeShareCreatedListener implements IEventListener {
 
 			$share->setTarget('/' . $receiverNotesInternalPath . $itemTarget);
 		} catch (\Throwable $e) {
+			if (isset($receiver)) {
+				$user = $this->userManager->get($receiver);
+				if ($user && $user->getBackendClassName() === 'Guests') {
+					return;
+				}
+			}
 			$this->logger->error('Failed to overwrite share target for notes', [
 				'exception' => $e,
 			]);
