@@ -2,6 +2,11 @@
 
 declare(strict_types=1);
 
+/**
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
+ */
+
 namespace OCA\Notes\Controller;
 
 use OCA\Notes\Service\SettingsService;
@@ -19,7 +24,7 @@ class SettingsController extends Controller {
 		string $appName,
 		IRequest $request,
 		SettingsService $service,
-		IUserSession $userSession
+		IUserSession $userSession,
 	) {
 		parent::__construct($appName, $request);
 		$this->service = $service;
@@ -48,4 +53,12 @@ class SettingsController extends Controller {
 	public function get(): JSONResponse {
 		return new JSONResponse($this->service->getAll($this->getUID()));
 	}
+
+	/**
+	 * @NoAdminRequired
+	 */
+	public function migrate(): JSONResponse {
+		$this->service->delete($this->getUID(), 'editorHint');
+		return new JSONResponse();
+	}
 }
