@@ -1,4 +1,11 @@
-<?php declare(strict_types=1);
+<?php
+
+declare(strict_types=1);
+
+/**
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
+ */
 
 namespace OCA\Notes\Db;
 
@@ -21,7 +28,6 @@ use OCP\AppFramework\Db\Entity;
  * @package OCA\Notes\Db
  */
 class Meta extends Entity {
-
 	protected $userId;
 	protected $fileId;
 	protected $lastUpdate;
